#!/bin/bash
#
# oppBanish 1.4.7 for IPCop 1.9.x based on Banish 1.4.7 for IPCop 1.4.18+
# Version 0.1
# oppBanish installation script

# Set Version Number
VERSION="0.1"

# Start Installation
echo -e "\033[1;32mStarting oppBanish 0.1 installation \033[0m"
/usr/bin/logger -t "oppbanish" "Starting oppBanish 0.1 Installation"
echo

# Check if files extracted to /tmp:
echo -e "Checking if files extracted to /tmp.\c"
if [ ! -d /tmp/oppbanish-0.1 ] ; 
	then
    	echo
    	echo
    	echo -e "\033[1;31mError!"
    	echo
    	echo "The files are not extracted to /tmp"
    	echo -e "Please extract oppbanish-0-1.tar.gz in /tmp!!\033[0m"
    	/usr/bin/logger -t "oppbanish" "oppBanish not extracted to /tmp, oppBanish installation aborted"
    	echo
     	exit 1
	else
		echo -e "...OK!"
fi
 

# Check if installation files exits
echo -e "Checking files......................\c"
if [ ! -f md5-check -o \
	  ! -f install_oppBanish.sh -o \
	  ! -f oppBanish.tar.gz ]
	then
		echo -e	"\033[1;31mError!"
	 	echo
	 	echo "One of the following files are missing"
	 	echo "md5-check"
	 	echo "install_oppBanish.sh"
	 	echo "oppBanish.tar.gz"
	 	echo
	 	echo -e "Please download file again. \033[0m"
	 	/usr/bin/logger -t "oppbanish" "oppBanish file check failed, oppBanish installation aborted"
	 	echo
	 	exit 1
	 else
		echo "...OK!"
fi	 

# Perform MD5SUM Check
echo -e "Checking md5sum.....................\c"

# Run check and capture output
md5sum -c md5-check >test 2>&1
WARNING=`cat test|grep FAILED`

if [ "$WARNING" ]
	 then
	 echo -e "\033[1;31mError!"
	 echo
	 echo -e "WARNING! MD5-check failed, installation aborted."
	 echo -e "Please download installation file again. \033[0m"
	 /usr/bin/logger -t "oppbanish" "MD5-check failed, oppBanish installation aborted"
	 echo
	 exit 1
	else
	 echo "...OK!"
fi

# Check for previous versions
if [ -x /usr/local/bin/uninstall_oppBanish.sh ]
   then
	echo
	echo -e "\033[1;33mPrevious installation detected \033[0m"
	
	# Backup oppBanish configuration files
	if [ -e /var/ipcop/oppBanish/ip_oppBanishlist ]
		then
		
		# Get current installed Banish Version
		BANVERSION=`cat /usr/local/bin/uninstall_oppBanish.sh|grep Version|awk ' { print $3 } '`
		
		# See if this will be an upgrade
		UPGRADE=`echo $VERSION $BANVERSION|awk '{ print ($1 > $2) ? "true" : "false" }'`
   		
		if [ "$UPGRADE" = "true" ]
			then
				echo
				echo -e "\033[1;33mUninstalling first \033[0m"
				cp -p /var/ipcop/oppBanish/ip_oppBanishlist .
				/usr/local/bin/uninstall_oppBanish.sh
				echo -e "\033[1;33mContinuing with install \033[0m"
			else
				echo
				echo -e "\033[1;33mYou have the current version of banish Banish installed"
				echo -e "To reinstall, run /usr/local/bin/uninstall_oppBanish.sh first"
				/usr/bin/logger -t "oppbanish" "Current version of oppBanish already installed"
				echo -e "Exiting installation \033[0m"
				echo
				exit 1
		fi
	fi			
fi

# Backup files
echo -e "Backing up files.....................\c"

/bin/mkdir /oppBanish >/dev/null 2>&1
/bin/cp -p /etc/rc.d/rc.event.local /oppBanish/rc.event.local.bak
echo "Done!"

# Extract files
echo -e "Extracting files.....................\c"
tar xzf oppBanish.tar.gz
echo "Done!"

# Install Banish files
echo -e "Installing system files..............\c"

# Install System files
/bin/cp -p oppBanish/usr/local/bin/* /usr/local/bin/

/bin/cp -p oppBanish/etc/rc.d/rc.oppBanish /etc/rc.d/rc.oppBanish

# Use previous configuration files if they exist
if [ -s ip_oppBanishlist ]
   	then
   		/bin/mkdir /var/ipcop/oppBanish
		/bin/cp -p ip_oppBanishlist /var/ipcop/oppBanish/
   	else
		# Make Banish directory and install files
		/bin/mkdir /var/ipcop/oppBanish
		/bin/cp -rp oppBanish/var/ipcop/oppBanish/* /var/ipcop/oppBanish/
fi

echo "Done!"

# Appending files
echo -e "Appending to files...................\c"

# Add call to rc.oppBanish from rc.event.local
/bin/cat oppBanish/oppBanish_rc.local.sh >>/etc/rc.d/rc.event.local
echo "Done!"

# Run oppBanish
echo -e "Starting oppBanish...................\c"
/etc/rc.d/rc.oppBanish start
echo "Done!"

# Cleaning up
echo -e "Cleaning up..........................\c"
/bin/rm -rf *
cd ..
/bin/rm -rf /tmp/oppbanish-0.1
echo -e  "Done!\n"

echo -e "\033[1;32moppBanish Installation Complete \033[0m"
/usr/bin/logger -t "oppbanish" "oppBanish 0.1 Installation Completed"
echo
echo -e  "To uninstall, run /usr/local/bin/uninstall_oppBanish.sh\n"
